==> ponyc-0.10.0-1-x86_64.pkg.tar.xz: usr/share/doc/pony/stdlib-docs/docs/collections-persistent--index.md <==
# Persistent Collections Package

List - A persistent list with functional transformations.

Map - A persistent map based on the Compressed Hash Array Mapped Prefix-tree
from 'Optimizing Hash-Array Mapped Tries for Fast and Lean Immutable JVM
Collections' by Michael J. Steindorfer and Jurgen J. Vinju


## Public Types

* [type List](collections-persistent-List.md)
* [primitive Lists](collections-persistent-Lists.md)
* [primitive Nil](collections-persistent-Nil.md)
* [class Cons](collections-persistent-Cons.md)
* [primitive Maps](collections-persistent-Maps.md)
* [class Map](collections-persistent-Map.md)
* [class MapKeys](collections-persistent-MapKeys.md)
* [class MapValues](collections-persistent-MapValues.md)
* [class MapPairs](collections-persistent-MapPairs.md)


## Private Types

* [type _MapCollisions](collections-persistent-_MapCollisions.md)
* [type _MapEntry](collections-persistent-_MapEntry.md)
* [class _MapNode](collections-persistent-_MapNode.md)
* [class _MapLeaf](collections-persistent-_MapLeaf.md)


## Test Types

* [actor Main](collections-persistent-Main.md)
* [class _TestListPrepend](collections-persistent-_TestListPrepend.md)
* [class _TestListFrom](collections-persistent-_TestListFrom.md)
* [class _TestListApply](collections-persistent-_TestListApply.md)
* [class _TestListValues](collections-persistent-_TestListValues.md)
* [class _TestListConcat](collections-persistent-_TestListConcat.md)
* [class _TestListMap](collections-persistent-_TestListMap.md)
* [class _TestListFlatMap](collections-persistent-_TestListFlatMap.md)
* [class _TestListFilter](collections-persistent-_TestListFilter.md)
* [class _TestListFold](collections-persistent-_TestListFold.md)
* [class _TestListEveryExists](collections-persistent-_TestListEveryExists.md)
* [class _TestListPartition](collections-persistent-_TestListPartition.md)
* [class _TestListDrop](collections-persistent-_TestListDrop.md)
* [class _TestListDropWhile](collections-persistent-_TestListDropWhile.md)
* [class _TestListTake](collections-persistent-_TestListTake.md)
* [class _TestListTakeWhile](collections-persistent-_TestListTakeWhile.md)
* [class _TestMap](collections-persistent-_TestMap.md)
* [class _TestMapVsMap](collections-persistent-_TestMapVsMap.md)

==> ponyc-0.11.0-1-x86_64.pkg.tar.xz: usr/share/doc/pony/stdlib-docs/docs/collections-persistent--index.md <==
# Persistent Collections Package

List - A persistent list with functional transformations.

Map - A persistent map based on the Compressed Hash Array Mapped Prefix-tree
from 'Optimizing Hash-Array Mapped Tries for Fast and Lean Immutable JVM
Collections' by Michael J. Steindorfer and Jurgen J. Vinju


## Public Types

* [type List](collections-persistent-List.md)
* [primitive Lists](collections-persistent-Lists.md)
* [primitive Nil](collections-persistent-Nil.md)
* [class Cons](collections-persistent-Cons.md)
* [primitive Maps](collections-persistent-Maps.md)
* [class Map](collections-persistent-Map.md)
* [class MapKeys](collections-persistent-MapKeys.md)
* [class MapValues](collections-persistent-MapValues.md)
* [class MapPairs](collections-persistent-MapPairs.md)


## Private Types

* [type _MapCollisions](collections-persistent-_MapCollisions.md)
* [type _MapLeaf](collections-persistent-_MapLeaf.md)
* [type _MapEntry](collections-persistent-_MapEntry.md)
* [class _MapNode](collections-persistent-_MapNode.md)


## Test Types

* [actor Main](collections-persistent-Main.md)
* [class _TestListPrepend](collections-persistent-_TestListPrepend.md)
* [class _TestListFrom](collections-persistent-_TestListFrom.md)
* [class _TestListApply](collections-persistent-_TestListApply.md)
* [class _TestListValues](collections-persistent-_TestListValues.md)
* [class _TestListConcat](collections-persistent-_TestListConcat.md)
* [class _TestListMap](collections-persistent-_TestListMap.md)
* [class _TestListFlatMap](collections-persistent-_TestListFlatMap.md)
* [class _TestListFilter](collections-persistent-_TestListFilter.md)
* [class _TestListFold](collections-persistent-_TestListFold.md)
* [class _TestListEveryExists](collections-persistent-_TestListEveryExists.md)
* [class _TestListPartition](collections-persistent-_TestListPartition.md)
* [class _TestListDrop](collections-persistent-_TestListDrop.md)
* [class _TestListDropWhile](collections-persistent-_TestListDropWhile.md)
* [class _TestListTake](collections-persistent-_TestListTake.md)
* [class _TestListTakeWhile](collections-persistent-_TestListTakeWhile.md)
* [class _TestMap](collections-persistent-_TestMap.md)
* [class _TestMapVsMap](collections-persistent-_TestMapVsMap.md)
